==> mule-tooling-api-1.1.3-hf1-sources.jar: org/mule/tooling/client/api/extension/model/ExternalLibraryModel.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.tooling.client.api.extension.model;

import static java.util.Optional.ofNullable;
import org.mule.tooling.client.api.extension.model.config.ConfigurationModel;

import java.util.Optional;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * Describes a library that the extension depends on but is not packaged with it.
 *
 * @since 1.0
 */
public class ExternalLibraryModel {

  private String name;
  private String description;
  private String requiredClassName;
  private String regexMatcher;
  private ExternalLibraryType type;
  private String suggestedCoordinates;
  private boolean optional;

  // Just needed in order to serialize this object
  private ExternalLibraryModel() {}

  public ExternalLibraryModel(String name, String description, String requiredClassName, String regexMatcher,
                              ExternalLibraryType type, String suggestedCoordinates, boolean optional) {
    this.name = name;
    this.description = description;
    this.requiredClassName = requiredClassName;
    this.regexMatcher = regexMatcher;
    this.type = type;
    this.suggestedCoordinates = suggestedCoordinates;
    this.optional = optional;
  }

  /**
   * @return The library's name. Will never be {@code null}
   */
  public String getName() {
    return name;
  }

  /**
   * @return The library's description
   */
  public String getDescription() {
    return description;
  }

  /**
   * If present, returns a regexp which must match the name of the library's file.
   *
   * @return An {@link Optional} regexp to match the library's file name
   */
  public Optional<String> getRegexMatcher() {
    return ofNullable(regexMatcher);
  }

  /**
   * If present, the library should contain a class of the given name
   *
   * @return The name of the required class
   */
  public Optional<String> getRequiredClassName() {
    return ofNullable(requiredClassName);
  }

  /**
   * @return The library's type
   */
  public ExternalLibraryType getType() {
    return type;
  }

  /**
   * If provided, suggests Maven coordinates where the required library can be found. This coordinates should
   * follow the Maven convention: {@code groupId:artifactId:packaging:classifier:version}.
   * <p>
   * Keep in mind that not all the values of the coordinates are required, for example:
   * {@code org.mule.modules:a-required-lib:1.0.0} are valid coordinates, which communicates the {@code groupId},
   * {@code artifactId} and {@code version} of the external library.
   * <p>
   * By default, the packaging is {@code jar}, so if is required to use a native library, like a .DLL, you will provide:
   * {@code org.mule.module:a-native-lib:dll:1.0.0} where {@code dll} is the packaging of the library.
   * <p>
   * More information in: <a href="https://maven.apache.org/pom.html#Maven_Coordinates">https://maven.apache.org/pom.html#Maven_Coordinates</a>
   *
   * @return The optional maven coordinates.
   */
  public Optional<String> getSuggestedCoordinates() {
    return ofNullable(suggestedCoordinates);
  }

  /**
   * @return A boolean indicating whether the library is required or not to the basic functioning of the connector.
   */
  public boolean isOptional() {
    return optional;
  }

  @Override
  public int hashCode() {
    return this.name.hashCode();
  }

  @Override
  public boolean equals(Object obj) {
    return this.getClass().isInstance(obj) && this.name.equals(((ConfigurationModel) obj).getName());
  }

  @Override
  public String toString() {
    return ToStringBuilder.reflectionToString(this);
  }

}

==> mule-tooling-api-1.2.2-hf1-sources.jar: org/mule/tooling/client/api/extension/model/ExternalLibraryModel.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.tooling.client.api.extension.model;

import static java.util.Optional.ofNullable;
import static org.mule.tooling.client.api.feature.Feature.disabled;
import static org.mule.tooling.client.api.feature.Feature.enabled;
import org.mule.tooling.client.api.extension.model.config.ConfigurationModel;
import org.mule.tooling.client.api.feature.Feature;

import java.util.Optional;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * Describes a library that the extension depends on but is not packaged with it.
 *
 * @since 1.0
 */
public class ExternalLibraryModel {

  private String name;
  private String description;
  private String requiredClassName;
  private String regexMatcher;
  private ExternalLibraryType type;
  private String suggestedCoordinates;
  private boolean optional;
  private Feature<Boolean> allowsDeclarationAsAdditionalDependency;

  // Just needed in order to serialize this object
  private ExternalLibraryModel() {}

  public ExternalLibraryModel(String name, String description, String requiredClassName, String regexMatcher,
                              ExternalLibraryType type, String suggestedCoordinates, boolean optional,
                              boolean allowsDeclarationAsAdditionalDependency) {
    this.name = name;
    this.description = description;
    this.requiredClassName = requiredClassName;
    this.regexMatcher = regexMatcher;
    this.type = type;
    this.suggestedCoordinates = suggestedCoordinates;
    this.optional = optional;
    this.allowsDeclarationAsAdditionalDependency = enabled(allowsDeclarationAsAdditionalDependency);
  }

  /**
   * @return The library's name. Will never be {@code null}
   */
  public String getName() {
    return name;
  }

  /**
   * @return The library's description
   */
  public String getDescription() {
    return description;
  }

  /**
   * If present, returns a regexp which must match the name of the library's file.
   *
   * @return An {@link Optional} regexp to match the library's file name
   */
  public Optional<String> getRegexMatcher() {
    return ofNullable(regexMatcher);
  }

  /**
   * If present, the library should contain a class of the given name
   *
   * @return The name of the required class
   */
  public Optional<String> getRequiredClassName() {
    return ofNullable(requiredClassName);
  }

  /**
   * @return The library's type
   */
  public ExternalLibraryType getType() {
    return type;
  }

  /**
   * If provided, suggests Maven coordinates where the required library can be found. This coordinates should
   * follow the Maven convention: {@code groupId:artifactId:packaging:classifier:version}.
   * <p>
   * Keep in mind that not all the values of the coordinates are required, for example:
   * {@code org.mule.modules:a-required-lib:1.0.0} are valid coordinates, which communicates the {@code groupId},
   * {@code artifactId} and {@code version} of the external library.
   * <p>
   * By default, the packaging is {@code jar}, so if is required to use a native library, like a .DLL, you will provide:
   * {@code org.mule.module:a-native-lib:dll:1.0.0} where {@code dll} is the packaging of the library.
   * <p>
   * More information in: <a href="https://maven.apache.org/pom.html#Maven_Coordinates">https://maven.apache.org/pom.html#Maven_Coordinates</a>
   *
   * @return The optional maven coordinates.
   */
  public Optional<String> getSuggestedCoordinates() {
    return ofNullable(suggestedCoordinates);
  }

  /**
   * @return A boolean indicating whether the library is required or not to the basic functioning of the connector.
   */
  public boolean isOptional() {
    return optional;
  }

  /**
   * @return A boolean indicating if the library can be added as additional dependency or should be shared by the application
   *
   * @since 1.2.0
   */
  public Feature<Boolean> allowsDeclarationAsAdditionalDependency() {
    if (allowsDeclarationAsAdditionalDependency == null) {
      return disabled();
    }
    return allowsDeclarationAsAdditionalDependency;
  }

  @Override
  public int hashCode() {
    return this.name.hashCode();
  }

  @Override
  public boolean equals(Object obj) {
    return this.getClass().isInstance(obj) && this.name.equals(((ConfigurationModel) obj).getName());
  }

  @Override
  public String toString() {
    return ToStringBuilder.reflectionToString(this);
  }

}
